==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/de_DE.php <==
<?php
$lang['friendlyname'] = 'Dateiverwaltung (FileManager)';
$lang['permission'] = 'Verwendung des FileManager-Moduls';
$lang['permissionadvanced'] = 'Weitere Optionen des FileManager-Moduls';
$lang['moddescription'] = 'Verwaltung von Dateien und Verzeichnissen im CMSms-Upload-Verzeichnis';
$lang['installed'] = 'Das FileManager-Modul wurde in der Version %s installiert';
$lang['postinstall'] = 'Das FileManager-Modul wurde installiert';
$lang['uninstalled'] = 'Das FileManager-Modul wurde deinstalliert';
$lang['really_uninstall'] = 'Wollen Sie das FileManager-Modul wirklich deinstallieren?';
$lang['upgraded'] = 'Das FileManager-Modul wurde auf Version %s aktualisiert';
$lang['fileview'] = 'Dateiansicht';
$lang['switchtofileview'] = 'Zur Datei-Anzeige wechseln';
$lang['settings'] = 'Einstellungen';
$lang['savesettings'] = 'Einstellungen speichern';
$lang['filename'] = 'Dateiname';
$lang['fileinfo'] = 'Datei-Info';
$lang['fileowner'] = 'Datei-Eigent&uuml;mer';
$lang['fileperms'] = 'Berechtigungen';
$lang['filesize'] = 'Gr&ouml;&szlig;e';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Aktionen';
$lang['delete'] = 'L&ouml;schen';
$lang['notwritable'] = 'Nicht beschreibbar';
$lang['filetoobig'] = 'ist zu gro&szlig;. Das Hochladen wurde abgebrochen.';
$lang['unknown'] = 'Unbekannt';
$lang['fileoutsideuploads'] = 'Sie sind nicht berechtigt, Dateien au&szlig;erhalb des uploads-Verzeichnisses zu ver&auml;ndern! (Daf&uuml;r ist die Berechtigung zur erweiterten Dateiverwaltung erforderlich)';
$lang['writable'] = 'Beschreibbar';
$lang['writeprotected'] = 'Schreibgesch&uuml;tzt';
$lang['bytes'] = 'Bytes';
$lang['kb'] = 'kB';
$lang['mb'] = 'MB';
$lang['files'] = 'Dateien';
$lang['bytesin'] = 'Bytes in';
$lang['in'] = 'in ';
$lang['file'] = 'Datei';
$lang['fileno'] = 'Datei-Nr. ';
$lang['subdirs'] = 'Unterverzeichnisse';
$lang['subdir'] = 'Unterverzeichnis';
$lang['and'] = 'und';
$lang['confirmsingledelete'] = 'Wollen Sie das wirklich?';
$lang['confirmsingledirdelete'] = 'Wollen Sie dieses Verzeichnis wirklich l&ouml;schen?';
$lang['dirtreedeletesuccess'] = 'Das Verzeichnis einschlie&szlig;lich des Inhalts wurde gel&ouml;scht.';
$lang['dirtreedeletefail'] = 'Beim L&ouml;schen des Verzeichnisses ist ein Fehler aufgetreten. Ein Teil der Inhalte sind m&ouml;glicherweise bereits gel&ouml;scht worden.';
$lang['singlefiledeletesuccess'] = 'Die Datei wurde gel&ouml;scht.';
$lang['filedeletesuccess'] = 'wurde gel&ouml;scht';
$lang['singlefiledeletefail'] = 'Beim L&ouml;schen der Datei ist ein Fehler aufgetreten.';
$lang['filedeletefail'] = 'wurde aufgrund eines Fehlers nicht gel&ouml;scht';
$lang['singledirdeletesuccess'] = 'Das Verzeichnis wurde gel&ouml;scht';
$lang['singledirdeletefail'] = 'Beim L&ouml;schen des Verzeichnisses ist ein Fehler aufgetreten (ist das Verzeichnis leer?)';
$lang['deleteselected'] = 'Die ausgew&auml;hlten Dateien l&ouml;schen';
$lang['confirmselected'] = 'Wollen Sie das wirklich?';
$lang['confirmdeleteselected'] = 'Wollen Sie die ausgew&auml;hlten Dateien wirklich l&ouml;schen?';
$lang['deleteselectedcancelled'] = 'Das L&ouml;schen der ausgew&auml;hlten Dateien wurde abgebrochen';
$lang['recursetext'] = 'Rekursiv mit allen Unterverzeichnissen';
$lang['nofilesselected'] = 'Keine Dateien ausgew&auml;hlt';
$lang['moveselected'] = 'Die ausgew&auml;hlten Dateien verschieben';
$lang['copyselected'] = 'Die ausgew&auml;hlten Dateien kopieren';
$lang['selecttargetdir'] = 'W&auml;hlen Sie das Zielverzeichnis f&uuml;r das Verschieben/Kopieren';
$lang['movedto'] = 'verschoben nach';
$lang['copiedto'] = 'kopiert nach';
$lang['couldnotmove'] = 'konnte nicht verschoben werden';
$lang['couldnotcopy'] = 'konnte nicht kopiert werden';
$lang['rename'] = 'Umbenennen';
$lang['newname'] = 'Neuer Name:';
$lang['renamesuccess'] = 'Die Datei wurde umbenannt';
$lang['renamefailure'] = 'Die Umbenennung der Datei ist fehlgeschlagen';
$lang['renamecancelled'] = 'Die Umbenennung der Datei wurde abgebrochen';
$lang['owner'] = 'Eigent&uuml;mer';
$lang['group'] = 'Gruppe';
$lang['others'] = 'Andere';
$lang['newpermissions'] = 'Neue Berechtigung:';
$lang['setpermissions'] = 'Berechtigung setzen';
$lang['permissionstyle'] = 'Berechtigungsstil';
$lang['rwxstyle'] = 'rwx';
$lang['755style'] = '755';
$lang['quickmode'] = 'Schneller chmod (z. Bsp. 777)';
$lang['chmod'] = 'Berechtigungen &auml;ndern';
$lang['chmodselected'] = 'Die Berechtigungen der ausgew&auml;hlten Dateien &auml;ndern';
$lang['chmodsuccess'] = 'Die Vergabe der neuen Berechtigungen war erfolgreich';
$lang['chmodfailure'] = 'Die &Auml;nderung der Berechtigung ist fehlgeschlagen';
$lang['chmodcancelled'] = 'Die &Auml;nderung der Berechtigung wurde abgebrochen';
$lang['dirchmodfailmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis ist gescheitert. Es ist jedoch m&ouml;glich, dass f&uuml;r einige Inhalte des Verzeichnisses trotzdem neue Berechtigungen gesetzt wurden.';
$lang['dirchmodsuccessmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis und dessen Inhalte war erfolgreich';
$lang['dirchmodsuccess'] = 'Dem Verzeichnis wurden die neuen Berechtigungen erfolgreich zugewiesen';
$lang['dirchmodfailure'] = 'Beim &Auml;ndern der Berechtigungen des Verzeichnisses ist ein Fehler aufgetreten';
$lang['dirnotemptyconfirm'] = 'Dieses Verzeichnis ist nicht leer. Wollen Sie es wirklich l&ouml;schen (einschlie&szlig;lich s&auml;mtlicher Inhalte und Unterverzeichnisse) ?';
$lang['dirtreedeletecancelled'] = 'Das L&ouml;schen des Verzeichnisses wurde abgebrochen';
$lang['imsure'] = 'Ich bin mir sicher';
$lang['cancel'] = 'Abbrechen';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Neue Datei(en) hochladen:';
$lang['unpackafterupload'] = 'Nach dem Hochladen die Datei entpacken (nur tgz und zip-Dateien)?';
$lang['uploadsuccess'] = 'wurde erfolgreich hochgeladen';
$lang['uploadfail'] = 'wurde nicht hochgeladen';
$lang['unpacksuccess'] = 'wurde erfolgreich entpackt';
$lang['unpackfail'] = 'wurde mit dem Fehler abgebrochen:';
$lang['packfileopenfail'] = 'Die gepackte Datei konnte nicht ge&ouml;ffnet werden (nicht unterst&uuml;tztes Format?)';
$lang['packfilewritefail'] = 'Die Datei %s konnte nicht geschrieben werden.';
$lang['currentpath'] = 'Aktueller Pfad:';
$lang['newdirname'] = 'Neues Verzeichnis erstellen:';
$lang['newdirsuccess'] = 'Das Verzeichnis wurde erfolgreich erstellt.';
$lang['newdirfail'] = 'Beim Erstellen des Verzeichnisses ist ein Fehler aufgetreten.';
$lang['invalidnewdir'] = 'Der Name des neuen Verzeichnisses darf keine Zeichen wie /, \ und &#039;..&#039; enthalten.';
$lang['filedateformat'] = 'd.m.Y H:m:s';
$lang['iconsize'] = 'Gr&ouml;&szlig;e der Icons';
$lang['smallicons'] = 'Klein';
$lang['largeicons'] = 'Gro&szlig;';
$lang['thousanddelimiter'] = 'Tausender-Trenner';
$lang['none'] = 'Nichts';
$lang['space'] = 'leer';
$lang['showthumbnails'] = 'Vorschaubilder anzeigen';
$lang['showthumbnailshelp'] = 'Mit dieser Option wird die Anzeige von Vorschaubildern (soweit vorhanden) f&uuml;r Bilddateien aktiviert. Ohne diese Option werden einfach nur alle Dateien angezeigt.';
$lang['uploadfilesto'] = 'Dateien hochladen in:';
$lang['uploadview'] = 'Hochzuladende Dateien';
$lang['uploadboxes'] = 'Anzahl der Felder f&uuml;r hochzuladende Dateien';
$lang['nothinguploaded'] = 'Nichts hochgeladen';
$lang['unsupportedarchive'] = 'Nicht unterst&uuml;tzte Archiv-Formate';
$lang['uploadmethod'] = 'Methode zum Hochladen';
$lang['uploaderstandard'] = 'Standard-HTML-Eingabemethode (erlaubt das Entpacken)';
$lang['enableadvanced'] = 'Erweiterten Modus aktivieren? (falls erlaubt)';
$lang['advancedhelp'] = 'Damit erhalten Sie Zugriff auf ALLE CMSms-Dateien (nicht nur auf das /uploads-Verzeichnis)';
$lang['showhiddenfileshelp'] = 'Ist nur bei Aktivierung des erweiterten Modus sinnvoll';
$lang['showhiddenfiles'] = 'Verborgene Dateien anzeigen';
$lang['settingsconfirmsingledelete'] = 'Das L&ouml;schen einzelner Datei best&auml;tigen?';
$lang['settingssaved'] = 'Einstellungen gespeichert';
$lang['help'] = '		<h3>Was macht das Modul?</h3>
		<p>Dieses Modul bietet verschiedene Funktionen zur Dateiverwaltung.</p>
		<h3>Wie wird es eingesetzt?</h3>
		<p>W&auml;hlen Sie das Modul in der Administration im Men&uuml; &quot;Inhalte&quot; aus.</p>';
$lang['qca'] = 'P0-617342851-1252404665837';
$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252408135.2';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/de_DE.php <==
<?php
$lang['friendlyname'] = 'Dateiverwaltung (FileManager)';
$lang['permission'] = 'Verwendung des FileManager-Moduls';
$lang['permissionadvanced'] = 'Weitere Optionen des FileManager-Moduls';
$lang['moddescription'] = 'Verwaltung von Dateien und Verzeichnissen im CMSms-Upload-Verzeichnis';
$lang['installed'] = 'Das FileManager-Modul wurde in der Version %s installiert';
$lang['postinstall'] = 'Das FileManager-Modul wurde installiert';
$lang['uninstalled'] = 'Das FileManager-Modul wurde deinstalliert';
$lang['really_uninstall'] = 'Wollen Sie das FileManager-Modul wirklich deinstallieren?';
$lang['upgraded'] = 'Das FileManager-Modul wurde auf Version %s aktualisiert';
$lang['fileview'] = 'Dateiansicht';
$lang['switchtofileview'] = 'Zur Datei-Anzeige wechseln';
$lang['settings'] = 'Einstellungen';
$lang['savesettings'] = 'Einstellungen speichern';
$lang['postletexists'] = 'Warnung! Bitte entfernen Sie aus Sicherheitsgr&uuml;nden das Verzeichnis /modules/FileManager/postlet vollst&auml;ndig - es wird schon seit einigen Versionen nicht mehr ben&ouml;tigt.';
$lang['filename'] = 'Dateiname';
$lang['fileinfo'] = 'Datei-Info';
$lang['fileowner'] = 'Datei-Eigent&uuml;mer';
$lang['fileperms'] = 'Berechtigungen';
$lang['filesize'] = 'Gr&ouml;&szlig;e';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Aktionen';
$lang['delete'] = 'L&ouml;schen';
$lang['notwritable'] = 'Nicht beschreibbar';
$lang['afileistoobig'] = 'Die Datei ist zu gro&szlig;. Das Hochladen wurde abgebrochen.';
$lang['unknown'] = 'Unbekannt';
$lang['fileoutsideuploads'] = 'Sie sind nicht berechtigt, Dateien au&szlig;erhalb des uploads-Verzeichnisses zu ver&auml;ndern! (Daf&uuml;r ist die Berechtigung zur erweiterten Dateiverwaltung erforderlich)';
$lang['writable'] = 'Beschreibbar';
$lang['writeprotected'] = 'Schreibgesch&uuml;tzt';
$lang['bytes'] = 'Bytes';
$lang['kb'] = 'kB';
$lang['mb'] = 'MB';
$lang['files'] = 'Dateien';
$lang['bytesin'] = 'Bytes in';
$lang['in'] = 'in ';
$lang['file'] = 'Datei';
$lang['fileno'] = 'Datei-Nr. ';
$lang['subdirs'] = 'Unterverzeichnisse';
$lang['subdir'] = 'Unterverzeichnis';
$lang['and'] = 'und';
$lang['confirmsingledelete'] = 'Wollen Sie das wirklich?';
$lang['confirmsingledirdelete'] = 'Wollen Sie dieses Verzeichnis wirklich l&ouml;schen?';
$lang['dirtreedeletesuccess'] = 'Das Verzeichnis einschlie&szlig;lich des Inhalts wurde gel&ouml;scht.';
$lang['dirtreedeletefail'] = 'Beim L&ouml;schen des Verzeichnisses ist ein Fehler aufgetreten. Ein Teil der Inhalte sind m&ouml;glicherweise bereits gel&ouml;scht worden.';
$lang['singlefiledeletesuccess'] = 'Die Datei wurde gel&ouml;scht.';
$lang['filedeletesuccess'] = 'wurde gel&ouml;scht';
$lang['singlefiledeletefail'] = 'Beim L&ouml;schen der Datei ist ein Fehler aufgetreten.';
$lang['filedeletefail'] = 'wurde aufgrund eines Fehlers nicht gel&ouml;scht';
$lang['singledirdeletesuccess'] = 'Das Verzeichnis wurde gel&ouml;scht';
$lang['singledirdeletefail'] = 'Beim L&ouml;schen des Verzeichnisses ist ein Fehler aufgetreten (ist das Verzeichnis leer?)';
$lang['deleteselected'] = 'Die ausgew&auml;hlten Dateien l&ouml;schen';
$lang['confirmselected'] = 'Wollen Sie das wirklich?';
$lang['confirmdeleteselected'] = 'Wollen Sie die ausgew&auml;hlten Dateien wirklich l&ouml;schen?';
$lang['deleteselectedcancelled'] = 'Das L&ouml;schen der ausgew&auml;hlten Dateien wurde abgebrochen';
$lang['recursetext'] = 'Rekursiv mit allen Unterverzeichnissen';
$lang['nofilesselected'] = 'Keine Dateien ausgew&auml;hlt';
$lang['moveselected'] = 'Die ausgew&auml;hlten Dateien verschieben';
$lang['copyselected'] = 'Die ausgew&auml;hlten Dateien kopieren';
$lang['selecttargetdir'] = 'W&auml;hlen Sie das Zielverzeichnis f&uuml;r das Verschieben/Kopieren';
$lang['movedto'] = 'verschoben nach';
$lang['copiedto'] = 'kopiert nach';
$lang['couldnotmove'] = 'konnte nicht verschoben werden';
$lang['couldnotcopy'] = 'konnte nicht kopiert werden';
$lang['filesdeletedsuccessfully'] = '%s Datei(en) wurde(n) gel&ouml;scht';
$lang['filesdeletedfiled'] = 'Bei %s Datei(en) ist das L&ouml;schen fehlgeschlagen';
$lang['filesmovedsuccessfully'] = '%s Datei(en) wurde(n) verschoben';
$lang['filesmovedfailed'] = 'Bei %s Datei(en) ist das Verschieben fehlgeschlagen';
$lang['filescopiedsuccessfully'] = '%s Datei(en) wurde(n) kopiert';
$lang['filescopiedfailed'] = 'Bei %s Datei(en) ist das Kopieren fehlgeschlagen';
$lang['internalerror'] = 'Interner Fehler (das bedeutet, irgend etwas macht keinen Sinn - bitte melden Sie uns m&ouml;glichst genau, was Sie getan haben)';
$lang['rename'] = 'Umbenennen';
$lang['newname'] = 'Neuer Name:';
$lang['renamesuccess'] = 'Die Datei wurde umbenannt';
$lang['renamefailure'] = 'Das Umbenennen der Datei ist fehlgeschlagen';
$lang['renamecancelled'] = 'Das Umbenennen der Datei wurde abgebrochen';
$lang['owner'] = 'Eigent&uuml;mer';
$lang['group'] = 'Gruppe';
$lang['others'] = 'Andere';
$lang['newpermissions'] = 'Neue Berechtigung:';
$lang['setpermissions'] = 'Berechtigung setzen';
$lang['permissionstyle'] = 'Berechtigungsstil';
$lang['rwxstyle'] = 'rwx';
$lang['755style'] = '755';
$lang['quickmode'] = 'Schneller chmod (z. Bsp. 777)';
$lang['chmod'] = 'Berechtigungen &auml;ndern';
$lang['chmodselected'] = 'Berechtigungen der ausgew&auml;hlten Dateien &auml;ndern';
$lang['chmodsuccess'] = 'Die Vergabe der neuen Berechtigungen war erfolgreich';
$lang['chmodfailure'] = 'Das &Auml;ndern der Berechtigung ist fehlgeschlagen';
$lang['chmodcancelled'] = 'Das &Auml;ndern der Berechtigung wurde abgebrochen';
$lang['newuploadfailed'] = 'Bei %s Datei(en) ist das hochladen oder m&ouml;glicherweise nur das Entpacken fehlgeschlagen';
$lang['newuploadsuccess'] = '%s Datei(en) wurde(n) hochgeladen und entpackt (falls ausgew&auml;hlt)';
$lang['dirchmodfailmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis ist fehlgeschlagen. Es ist jedoch m&ouml;glich, dass f&uuml;r einige Inhalte des Verzeichnisses trotzdem neue Berechtigungen gesetzt wurden.';
$lang['dirchmodsuccessmulti'] = 'Die Berechtigungen f&uuml;r das Verzeichnis und dessen Inhalte wurden ge&auml;ndert';
$lang['dirchmodsuccess'] = 'Dem Verzeichnis wurden die neuen Berechtigungen zugewiesen';
$lang['dirchmodfailure'] = 'Beim &Auml;ndern der Berechtigungen des Verzeichnisses ist ein Fehler aufgetreten';
$lang['dirnotemptyconfirm'] = 'Dieses Verzeichnis ist nicht leer. Wollen Sie es wirklich l&ouml;schen (einschlie&szlig;lich s&auml;mtlicher Inhalte und Unterverzeichnisse) ?';
$lang['dirtreedeletecancelled'] = 'Das L&ouml;schen des Verzeichnisses wurde abgebrochen';
$lang['imsure'] = 'Ich bin mir sicher';
$lang['cancel'] = 'Abbrechen';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Neue Datei(en) hochladen:';
$lang['unpackafterupload'] = 'Nach dem Hochladen die Datei entpacken (nur tgz und zip-Dateien)?';
$lang['uploadsuccess'] = 'wurde hochgeladen';
$lang['uploadfail'] = 'wurde nicht hochgeladen';
$lang['unpacksuccess'] = 'wurde entpackt';
$lang['unpackfail'] = 'wurde mit dem Fehler abgebrochen:';
$lang['packfileopenfail'] = 'Die gepackte Datei konnte nicht ge&ouml;ffnet werden (nicht unterst&uuml;tztes Format?)';
$lang['packfilewritefail'] = 'Die Datei %s konnte nicht geschrieben werden.';
$lang['afilecontainsillegalchars'] = 'Der Dateiname enth&auml;lt einen oder mehrere unzul&auml;ssige Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$). Das Hochladen wurde abgebrochen.';
$lang['currentpath'] = 'Aktueller Pfad:';
$lang['newdirname'] = 'Neues Verzeichnis erstellen:';
$lang['newdirsuccess'] = 'Das Verzeichnis wurde erstellt.';
$lang['newdirfail'] = 'Beim Erstellen des Verzeichnisses ist ein Fehler aufgetreten.';
$lang['direxists'] = 'Ein Verzeichnis mit diesem Namen existiert bereits';
$lang['invalidnewdir'] = 'Der Name des neuen Verzeichnisses darf keine Zeichen wie /, \ und &#039;..&#039; enthalten.';
$lang['filedateformat'] = 'd.m.Y H:m:s';
$lang['iconsize'] = 'Gr&ouml;&szlig;e der Icons';
$lang['smallicons'] = 'Klein';
$lang['largeicons'] = 'Gro&szlig;';
$lang['thousanddelimiter'] = 'Tausender-Trenner';
$lang['none'] = 'Nichts';
$lang['space'] = 'leer';
$lang['showthumbnails'] = 'Vorschaubilder anzeigen';
$lang['showthumbnailshelp'] = 'Mit dieser Option wird die Anzeige von Vorschaubildern (soweit vorhanden) f&uuml;r Bilddateien aktiviert. Ohne diese Option werden einfach nur alle Dateien angezeigt.';
$lang['uploadfilesto'] = 'Dateien hochladen in:';
$lang['uploadview'] = 'Hochzuladende Dateien';
$lang['uploadboxes'] = 'Anzahl der Felder f&uuml;r hochzuladende Dateien';
$lang['nothinguploaded'] = 'Nichts hochgeladen';
$lang['newunsupportedarchive'] = '%s ist ein nicht unterst&uuml;tztes Archiv-Format';
$lang['uploadmethod'] = 'Methode zum Hochladen';
$lang['uploaderstandard'] = 'Standard-HTML-Eingabemethode (erlaubt das Entpacken)';
$lang['enableadvanced'] = 'Erweiterten Modus aktivieren?';
$lang['advancedhelp'] = 'Damit erhalten Sie Zugriff auf ALLE CMSms-Dateien, nicht nur auf das /uploads-Verzeichnis (falls erlaubt)';
$lang['showhiddenfileshelp'] = 'Ist nur bei Aktivierung des erweiterten Modus sinnvoll';
$lang['showhiddenfiles'] = 'Verborgene Dateien anzeigen';
$lang['settingsconfirmsingledelete'] = 'Das L&ouml;schen einzelner Datei best&auml;tigen?';
$lang['settingssaved'] = 'Einstellungen gespeichert';
$lang['help'] = '		<h3>Was macht das Modul?</h3>
		<p>Dieses Modul bietet verschiedene Funktionen zur Dateiverwaltung.</p>
		<h3>Wie wird es eingesetzt?</h3>
		<p>W&auml;hlen Sie das Modul in der Administration im Men&uuml; &quot;Inhalte&quot; aus.</p>';
$lang['utma'] = '156861353.1653174585.1296045220.1296045220.1296045220.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1296045220.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>
